==> image_card_list-0.0.1.tar.gz: lib/image_card_list.dart <==
library image_card_list;

import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';

/*
//Usage:
ImageCardList(
        map: {
          "Ironman": "assets/ironman.png",
          "Captain America": "assets/captainamerica.jpg",
          "Thor": "assets/thor.png",
          "Hulk": "assets/hulk.jpg",
          "Black Panther": "assets/blackpanther.jpg",
          "Hawkeye": "assets/hawkeye.jpg",
        },
        displayNameTag: true,
        // align: NameTagAlign.left,
        // borderRadius: 20.0,
        // padding: EdgeInsets.all(10.0),
        // elevation: 10.0,
        // fontSize: 30.0,
        // color: Colors.red,
        // height: 300,
        // width: 300,
        // shadowColor: Colors.green,
        // spacing: 10.0,
        // titleColor: Colors.yellow,
        //scrollDirection: Axis.vertical,
      )
*/
class ImageCardList extends StatelessWidget {
  ImageCardList({
    Key key,
    @required this.map,
    @required this.displayNameTag,
    this.height = 200.0,
    this.width = 200.0,
    this.titleColor = Colors.black,
    this.fontSize = 20.0,
    this.borderRadius = 5.0,
    this.padding = const EdgeInsets.all(5.0),
    this.spacing = 5.0,
    this.elevation = 1.0,
    this.align = NameTagAlign.center,
    this.color = Colors.white,
    this.shadowColor = Colors.grey,
    this.scrollDirection = Axis.horizontal,
    this.semanticContainer = false,
  })  : assert(map != null),
        assert(height >= 50.0),
        assert(width >= 50.0),
        assert(!(fontSize < 0)),
        assert(!(borderRadius < 0)),
        assert(!(spacing < 0)),
        assert(!(elevation < 0)),
        super(key: key);

  final Map<String, String> map;
  final Axis scrollDirection;
  final bool displayNameTag;
  final double height;
  final double width;
  final double fontSize;
  final double borderRadius;
  final Color titleColor;
  final double elevation;
  final EdgeInsetsGeometry padding;
  final double spacing;
  final NameTagAlign align;
  final Color color;
  final Color shadowColor;
  final bool semanticContainer;

  static ImageCardList of(BuildContext context) {
    return context
        .dependOnInheritedWidgetOfExactType<_FieldsWidget>()
        .imageCardList;
  }

  @override
  Widget build(BuildContext context) {
    List<_ImageCard> list = List();
    if (displayNameTag) {
      map.forEach((key, value) {
        list.add(_ImageCard(
          imagePath: value,
          imageTitle: key,
        ));
      });
    } else {
      map.forEach((key, value) {
        list.add(_ImageCard(
          imagePath: value,
        ));
      });
    }

    return _FieldsWidget(
      imageCardList: this,
      child: Container(
        child: Padding(
          padding: const EdgeInsets.all(8.0),
          child: scrollDirection == Axis.horizontal
              ? SingleChildScrollView(
                  scrollDirection: scrollDirection,
                  child: Row(
                    children: list,
                  ),
                )
              : SingleChildScrollView(
                  scrollDirection: scrollDirection,
                  child: Column(
                    children: list,
                  ),
                ),
        ),
      ),
    );
  }
}

class _ImageCard extends StatelessWidget {
  _ImageCard({
    Key key,
    @required this.imagePath,
    this.imageTitle,
  }) : super(key: key);

  final String imagePath;
  final String imageTitle;

  @override
  Widget build(BuildContext context) {
    var hicl = ImageCardList.of(context);
    return Card(
      color: hicl.color,
      semanticContainer: hicl.semanticContainer,
      shadowColor: hicl.shadowColor,
      elevation: hicl.elevation,
      shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(hicl.borderRadius)),
      child: Padding(
        padding: hicl.padding,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: hicl.align == NameTagAlign.left
              ? CrossAxisAlignment.start
              : hicl.align == NameTagAlign.right
                  ? CrossAxisAlignment.end
                  : CrossAxisAlignment.center,
          children: <Widget>[
            _ImageView(
              height: imageTitle == null
                  ? hicl.height
                  : hicl.height - (hicl.fontSize + 5),
              width: hicl.width,
              imagePath: imagePath,
            ),
            imageTitle != null
                ? Padding(
                    padding: EdgeInsets.only(top: hicl.spacing),
                    child: Text(
                      imageTitle,
                      style: TextStyle(
                        color: hicl.titleColor,
                        fontSize: hicl.fontSize,
                      ),
                    ),
                  )
                : Container(),
          ],
        ),
      ),
    );
  }
}

enum NameTagAlign { left, right, center }

class _FieldsWidget extends InheritedWidget {
  final ImageCardList imageCardList;

  _FieldsWidget({
    Key key,
    @required this.imageCardList,
    @required Widget child,
  }) : super(key: key, child: child);

  @override
  bool updateShouldNotify(_FieldsWidget oldWidget) => true;
}

class _ImageView extends StatelessWidget {
  _ImageView({
    Key key,
    @required this.imagePath,
    this.height = 200.0,
    this.width = 200.0,
  }) : super(key: key);

  final String imagePath;
  final double height;
  final double width;

  @override
  Widget build(BuildContext context) {
    return Container(
      height: height,
      width: width,
      decoration: BoxDecoration(
        image: DecorationImage(
          image: AssetImage(imagePath),
          fit: BoxFit.fill,
          alignment: Alignment.topCenter,
        ),
      ),
    );
  }
}

==> image_card_list-0.0.2.tar.gz: lib/image_card_list.dart <==
library image_card_list;

import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';

class ImageCardList extends StatelessWidget {
  ImageCardList({
    Key key,
    @required this.map,
    @required this.displayNameTag,
    this.height = 200.0,
    this.width = 200.0,
    this.titleColor = Colors.black,
    this.fontSize = 20.0,
    this.borderRadius = 5.0,
    this.padding = const EdgeInsets.all(5.0),
    this.spacing = 5.0,
    this.elevation = 1.0,
    this.align = NameTagAlign.center,
    this.color = Colors.white,
    this.shadowColor = Colors.grey,
    this.scrollDirection = Axis.horizontal,
    this.semanticContainer = false,
    this.margin = const EdgeInsets.all(8.0),
    this.reverse = false,
  })  : assert(map != null),
        assert(height >= 50.0),
        assert(width >= 50.0),
        assert(!(fontSize < 0)),
        assert(!(borderRadius < 0)),
        assert(!(spacing < 0)),
        assert(!(elevation < 0)),
        super(key: key);

  final Map<String, String> map;
  final Axis scrollDirection;
  final bool displayNameTag;
  final double height;
  final double width;
  final double fontSize;
  final double borderRadius;
  final Color titleColor;
  final double elevation;
  final EdgeInsetsGeometry padding;
  final double spacing;
  final NameTagAlign align;
  final Color color;
  final Color shadowColor;
  final bool semanticContainer;
  final bool reverse;
  final EdgeInsetsGeometry margin;

  static ImageCardList of(BuildContext context) {
    return context
        .dependOnInheritedWidgetOfExactType<_FieldsWidget>()
        .imageCardList;
  }

  @override
  Widget build(BuildContext context) {
    List<_ImageCard> list = List();
    
    if (displayNameTag) {
      map.forEach((key, value) {
        list.add(_ImageCard(
          imagePath: value,
          imageTitle: key,
        ));
      });
    } else {
      map.forEach((key, value) {
        list.add(_ImageCard(
          imagePath: value,
        ));
      });
    }

    return _FieldsWidget(
      imageCardList: this,
      child: Container(
        child: scrollDirection == Axis.horizontal
            ? SingleChildScrollView(
                reverse: reverse,
                padding: margin,
                scrollDirection: scrollDirection,
                child: Row(
                  children: list,
                ),
              )
            : SingleChildScrollView(
                reverse: reverse,
                padding: margin,
                scrollDirection: scrollDirection,
                child: Column(
                  children: list,
                ),
              ),
      ),
    );
  }
}

class _ImageCard extends StatelessWidget {
  _ImageCard({
    Key key,
    @required this.imagePath,
    this.imageTitle,
  }) : super(key: key);

  final String imagePath;
  final String imageTitle;

  @override
  Widget build(BuildContext context) {
    var hicl = ImageCardList.of(context);
    return Card(
      color: hicl.color,
      semanticContainer: hicl.semanticContainer,
      shadowColor: hicl.shadowColor,
      elevation: hicl.elevation,
      shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(hicl.borderRadius)),
      child: Padding(
        padding: hicl.padding,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: hicl.align == NameTagAlign.left
              ? CrossAxisAlignment.start
              : hicl.align == NameTagAlign.right
                  ? CrossAxisAlignment.end
                  : CrossAxisAlignment.center,
          children: <Widget>[
            _ImageView(
              height: imageTitle == null
                  ? hicl.height
                  : hicl.height - (hicl.fontSize + 5),
              width: hicl.width,
              imagePath: imagePath,
            ),
            imageTitle != null
                ? Padding(
                    padding: EdgeInsets.only(top: hicl.spacing),
                    child: Text(
                      imageTitle,
                      style: TextStyle(
                        color: hicl.titleColor,
                        fontSize: hicl.fontSize,
                      ),
                    ),
                  )
                : Container(),
          ],
        ),
      ),
    );
  }
}

enum NameTagAlign { left, right, center }

class _FieldsWidget extends InheritedWidget {
  final ImageCardList imageCardList;

  _FieldsWidget({
    Key key,
    @required this.imageCardList,
    @required Widget child,
  }) : super(key: key, child: child);

  @override
  bool updateShouldNotify(_FieldsWidget oldWidget) => true;
}

class _ImageView extends StatelessWidget {
  _ImageView({
    Key key,
    @required this.imagePath,
    this.height = 200.0,
    this.width = 200.0,
  }) : super(key: key);

  final String imagePath;
  final double height;
  final double width;

  @override
  Widget build(BuildContext context) {
    return Container(
      height: height,
      width: width,
      decoration: BoxDecoration(
        image: DecorationImage(
          image: imagePath.contains("http")?Image.network(imagePath).image:AssetImage(imagePath),
          fit: BoxFit.fill,
          alignment: Alignment.topCenter,
        ),
      ),
    );
  }
}
